==========
Send words
==========


.. image:: https://img.shields.io/pypi/v/send_words.svg
        :target: https://pypi.python.org/pypi/send_words

.. image:: https://img.shields.io/travis/bgarcial/send_words.svg
        :target: https://travis-ci.org/bgarcial/send_words

.. image:: https://readthedocs.org/projects/send-words/badge/?version=latest
        :target: https://send-words.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Package that send a word or words set to service and get the syllabes of each phrase sent and show some random quotes

pip install send_words

* Free software: MIT license
* Documentation: https://send-words.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
